==> masamune_firebase-0.2.2.tar.gz: lib/masamune_firebase.dart <==
// Copyright 2020 mathru. All rights reserved.

/// Masamune firebase framework library
///
/// To use, import `package:masamune_firebase/masamune_firebase.dart`.
/// 
/// [mathru.net]: https://mathru.net
/// [YouTube]: https://www.youtube.com/c/mathrunetchannel
library masamune.firebase;
import 'dart:async';
import 'dart:collection';
import 'dart:io';
import 'package:cloud_functions/cloud_functions.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_storage/firebase_storage.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:flutter_twitter/flutter_twitter.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:masamune_core/masamune_core.dart';

part 'interface/ifirestorechangelistener.dart';
part 'interface/ifirestorecollection.dart';

part 'core/firestorequerytype.dart';
part 'core/typedef.dart';
part 'core/firestorequery.dart';
part 'core/firestoremeta.dart';

part 'firebase/firebase.dart';
part 'firebase/firestoreauth.dart';
part 'firebase/firestorestorage.dart';

part 'firestore/firestoredocument.dart';
part 'firestore/firestorecollection.dart';
part 'firestore/searchablefirestorecollection.dart';

part 'functions/firestorefunctions.dart';
part 'functions/functionstask.dart';
part 'functions/functionsdocument.dart';
part 'functions/functionscollection.dart';

==> masamune_firebase-0.2.3.tar.gz: lib/masamune_firebase.dart <==
// Copyright 2020 mathru. All rights reserved.

/// Masamune firebase framework library
///
/// To use, import `package:masamune_firebase/masamune_firebase.dart`.
/// 
/// [mathru.net]: https://mathru.net
/// [YouTube]: https://www.youtube.com/c/mathrunetchannel
library masamune.firebase;
import 'dart:async';
import 'dart:collection';
import 'dart:io';
import 'package:http/http.dart';
import 'package:package_info/package_info.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:firebase_dynamic_links/firebase_dynamic_links.dart';
import 'package:firebase_remote_config/firebase_remote_config.dart';
import 'package:firebase_storage/firebase_storage.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:flutter_twitter/flutter_twitter.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:masamune_core/masamune_core.dart';
export 'package:masamune_core/masamune_core.dart';

part 'config/appconfigdocument.dart';
part 'config/remoteconfigdocument.dart';

part 'interface/ifirestorechangelistener.dart';
part 'interface/ifirestorecollection.dart';

part 'core/firestorequerytype.dart';
part 'core/typedef.dart';
part 'core/firestorequery.dart';
part 'core/firestoremeta.dart';

part 'firebase/firebase.dart';

part 'firestore/firestoredocument.dart';
part 'firestore/firestorecollection.dart';
part 'firestore/searchablefirestorecollection.dart';

part 'auth/firestoreauth.dart';

part 'storage/firestorestorage.dart';

part 'dynamiclink/firestoredynamiclinkuri.dart';
